/**************************************************************************
** 
** File name   : replication_interactions.do
** Date        : May 7th, 2012
** Author      : Christina J. Schneider (cjschneider@ucsd.edu)
** Paper	   : Domestic Elections, Political Competence, and Distributional 
					Bargaining in the European Union
** Purpose     : Replicate Figures 3-7
** Requires    : replication.dta, replication_main.do, replication_robustness.do,
					replication_interactions.do, replications_appendices.do
** Output      : replication.log, figure2a.eps, figure3a.eps, figure4a.eps, 
					figure5a.eps, figure6a.eps, figure7a.eps, figure2b.eps, 
					figure3b.eps, figure4b.eps, figure5b.eps, figure6b.eps, 
					figure7b.eps
**
**************************************************************************/ 


#delimit ;

**FIGURE 3A**;

xtpcse ccap_pct preelection unemployment preunemployment  election_year employagri_ln gdppercap_eu100 
sscouncil_pct eusupport 	newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>213;
replace MV=. if _n<5;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<213 & _n>5;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<213 & _n>5;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(2)22)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Unemployment (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure3a.eps", replace; 
drop MV-lower; 


**FIGURE 3B**;

xtpcse ccsp_pct preelection unemployment preunemployment  election_year employagri_ln gdppercap_eu100 
sscouncil_pct eusupport 	newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>213;
replace MV=. if _n<5;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<213 & _n>5;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<213 & _n>5;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(2)22)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Unemployment (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure3b, replace ;    
drop MV-lower; 


**FIGURE 4A**;

xtpcse ccap_pct preelection incumbent_votes_pct prevotes  election_year employagri_ln gdppercap_eu100 
unemployment sscouncil_pct eusupport 	newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>660;
replace MV=. if _n<57;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<660 & _n>57;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<660 & _n>57;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(10)70)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle( Public Incumbent Support (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure4a, replace; 

drop MV-lower; 


**FIGURE 4B**;

xtpcse ccsp_pct preelection incumbent_votes_pct prevotes  election_year employagri_ln gdppercap_eu100 
unemployment sscouncil_pct eusupport 	newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>660;
replace MV=. if _n<57;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<660 & _n>57;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<660 & _n>57;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(10)70)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle( Public Incumbent Support (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

 

graph export figure4b, replace ;
drop MV-lower; 




**FIGURE 5A**;


xtpcse ccap_pct preelection dont_know_pct predontknow  election_year employagri_ln gdppercap_eu100 unemployment 
	sscouncil_pct eusupport newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>490;
replace MV=. if _n<5;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<490 & _n>5;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<490 & _n>5;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;

graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(5)50)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Undecided Voters (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure5a, replace ; 
drop MV-lower; 

**FIGURE 5B**;

xtpcse ccsp_pct preelection dont_know_pct predontknow  election_year employagri_ln gdppercap_eu100 unemployment 
	sscouncil_pct eusupport newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>490;
replace MV=. if _n<5;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<490 & _n>5;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<490 & _n>5;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;
#delimit;
graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(5)50)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Undecided Voters (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure5b, replace ; 
drop MV-lower; 


**FIGURE 6A**;

xtpcse ccap_pct preelection sscouncil_pct prepower election_year employagri_ln gdppercap_eu100 unemployment  eusupport 
	newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>180;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<180;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<180;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;


graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(2)18)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Voting Power (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure6a, replace ;     
drop MV-lower; 


**FIGURE 6B**;

xtpcse ccsp_pct preelection sscouncil_pct prepower election_year employagri_ln gdppercap_eu100 unemployment  eusupport 
	newmember size   id_*, correlation(psar1);

generate MV=((_n-1)/10);
replace  MV=. if _n>180;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<180;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<180;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;


graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(0(2)18)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Voting Power (in %), size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure6b, replace ; 
drop MV-lower; 


**FIGURE 7**;

xtpcse ctot_pct preelection partisan_diff prepartisandiff election_year  employagri_ln gdppercap_eu100   unemployment sscouncil_pct eusupport 
	newmember size  id_*, correlation(psar1) pairwise;

generate MV=-5+((_n-1)/10);
replace  MV=. if _n>100;
matrix b=e(b) ;
matrix V=e(V);
scalar b1=b[1,1] ;
scalar b2=b[1,2];
scalar b3=b[1,3];
scalar varb1=V[1,1];
scalar varb2=V[2,2];
scalar varb3=V[3,3];
scalar covb1b3=V[1,3];
scalar covb2b3=V[2,3];
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3;
gen conb=b1+b3*MV if _n<100  ;
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<100  ;
gen a=1.65*conse;
gen upper=conb+a;
gen lower=conb-a;


graph twoway line conb   MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   ,   
            
             xlabel(-5(1)5)
             
             
             legend(col(1) order(1 2) label(1 "Marginal Effect of Preelection") 
                                      label(2 "90% Confidence Interval") 
                                      label(3 " "))
             yline(0, lcolor(black))   
             
             
             xtitle(Partisan Difference, size(3)  )
             xsca(titlegap(2))
             ysca(titlegap(2))
             ytitle("Marginal Effect of Preelection", size(3))
             scheme(s2mono) graphregion(fcolor(white));

graph export figure7, replace ;        
drop MV-lower; 


exit;

